Imported from libpng-1.0.11beta2.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index 66dd338..8117e75 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.0.11beta1 - April 4, 2001
+Libpng 1.0.11beta2 - April 11, 2001
 
 This is a public release of libpng, intended for use in production codes.
 
@@ -8,6 +8,8 @@
   Added type casts on several png_malloc() calls (Dimitri Papadapoulos).
   Removed a no-longer needed AIX work-around from pngconf.h
   Changed several "//" single-line comments to C-style in pnggccrd.c
+  Removed PNGAPI from private functions whose prototypes did not have PNGAPI.
+  Updated scripts/pngos2.def
 
 Send comments/corrections/commendations to
 png-implement@ccrc.wustl.edu or to randeg@alum.rpi.edu
diff --git a/CHANGES b/CHANGES
index b595332..eecd51f 100644
--- a/CHANGES
+++ b/CHANGES
@@ -914,10 +914,13 @@
 version 1.0.10 [March 30, 2001]
   Deleted extraneous space (introduced in 1.0.9) from line 42 of makefile.cygwin
   Added beos project files (Chris Herborth)
-version 1.0.11beta1 [April 4, 2001]
+version 1.0.11beta1 [April 3, 2001]
   Added type casts on several png_malloc() calls (Dimitri Papadapoulos).
   Removed a no-longer needed AIX work-around from pngconf.h
   Changed several "//" single-line comments to C-style in pnggccrd.c
+version 1.0.11beta2 [April 11, 2001]
+  Removed PNGAPI from several functions whose prototypes did not have PNGAPI.
+  Updated scripts/pngos2.def
 
 Send comments/corrections/commendations to
 png-implement@ccrc.wustl.edu or to randeg@alum.rpi.edu
diff --git a/INSTALL b/INSTALL
index 41332b7..da03eba 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.0.11beta1 - April 4, 2001
+Installing libpng version 1.0.11beta2 - April 11, 2001
 
 Before installing libpng, you must first install zlib.  zlib
 can usually be found wherever you got libpng.  zlib can be
@@ -10,7 +10,7 @@
 version of zlib that's installed.
 
 You can rename the directories that you downloaded (they
-might be called "libpng-1.0.11beta1" or "lpng109" and "zlib-1.1.3"
+might be called "libpng-1.0.11beta2" or "lpng109" and "zlib-1.1.3"
 or "zlib113") so that you have directories called "zlib" and "libpng".
 
 Your directory structure should look like this:
@@ -60,8 +60,8 @@
 include
 
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
- makefile.linux    =>  Linux/ELF makefile (gcc, creates libpng.so.2.1.0.11beta1)
- makefile.gcmmx    =>  Linux/ELF makefile (gcc, creates libpng.so.2.1.0.11beta1,
+ makefile.linux    =>  Linux/ELF makefile (gcc, creates libpng.so.2.1.0.11beta2)
+ makefile.gcmmx    =>  Linux/ELF makefile (gcc, creates libpng.so.2.1.0.11beta2,
                        uses assembler code tuned for Intel MMX platform)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
@@ -77,9 +77,9 @@
  libpng.icc        =>  Project file for IBM VisualAge/C++ version 4.0 or later
  makefile.macosx   =>  MACOS X Makefile
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
- makefile.sggcc    =>  Silicon Graphics (gcc, creates libpng.so.2.1.0.11beta1)
+ makefile.sggcc    =>  Silicon Graphics (gcc, creates libpng.so.2.1.0.11beta2)
  makefile.sunos    =>  Sun makefile
- makefile.solaris  =>  Solaris 2.X makefile (gcc, creates libpng.so.2.1.0.11beta1)
+ makefile.solaris  =>  Solaris 2.X makefile (gcc, creates libpng.so.2.1.0.11beta2)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.mips     =>  MIPS makefile
  makefile.acorn    =>  Acorn makefile
diff --git a/KNOWNBUG b/KNOWNBUG
index 174f48c..3477ba8 100644
--- a/KNOWNBUG
+++ b/KNOWNBUG
@@ -13,3 +13,11 @@
    compile pnggccrd.c (Richard Kettlewell).
 
    STATUS: fixed in libpng-1.0.11beta1.
+
+3. April 5, 2001: The prototypes don't match several functions.
+
+   Functions png_info_init, png_zalloc, and several others have PNGAPI
+   in the C functions but not in the prototypes in png.h.  The functions
+   involved are all either deprecated or intended only for internal use.
+
+   STATUS: PNGAPI was removed from the C code in libpng-1.0.11beta2.
diff --git a/LICENSE b/LICENSE
index e16e77e..fdeec35 100644
--- a/LICENSE
+++ b/LICENSE
@@ -8,7 +8,7 @@
 If you modify libpng you may insert additional notices immediately following
 this sentence.
 
-libpng versions 1.0.7, July 1, 2000, through 1.0.11beta1, April 4, 2001, are
+libpng versions 1.0.7, July 1, 2000, through 1.0.11beta2, April 11, 2001, are
 Copyright (c) 2000, 2001 Glenn Randers-Pehrson
 and are distributed according to the same disclaimer and license as libpng-1.0.6
 with the following individuals added to the list of Contributing Authors
@@ -99,4 +99,4 @@
 
 Glenn Randers-Pehrson
 randeg@alum.rpi.edu
-April 4, 2001
+April 11, 2001
diff --git a/README b/README
index 3c931f5..be1067f 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng 1.0.11beta1 - April 4, 2001 (shared library 2.1)
+README for libpng 1.0.11beta2 - April 11, 2001 (shared library 2.1)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
@@ -183,9 +183,9 @@
        descrip.mms      =>  VMS makefile for MMS or MMK
        makefile.std     =>  Generic UNIX makefile (cc, creates static libpng.a)
        makefile.linux   =>  Linux/ELF makefile
-                            (gcc, creates libpng.so.2.1.0.11beta1)
+                            (gcc, creates libpng.so.2.1.0.11beta2)
        makefile.gcmmx   =>  Linux/ELF makefile (gcc, creates
-                            libpng.so.2.1.0.11beta1, uses assembler code
+                            libpng.so.2.1.0.11beta2, uses assembler code
                             tuned for Intel MMX platform)
        makefile.gcc     =>  Generic makefile (gcc, creates static libpng.a)
        makefile.knr     =>  Archaic UNIX Makefile that converts files with
@@ -201,10 +201,10 @@
        libpng.icc       =>  Project file, IBM VisualAge/C++ 4.0 or later
        makefile.macosx  =>  MACOS X Makefile
        makefile.sgi     =>  Silicon Graphics IRIX (cc, creates static lib)
-       makefile.sggcc   =>  Silicon Graphics (gcc, creates libpng.so.2.1.0.11beta1)
+       makefile.sggcc   =>  Silicon Graphics (gcc, creates libpng.so.2.1.0.11beta2)
        makefile.sunos   =>  Sun makefile
        makefile.solaris =>  Solaris 2.X makefile
-                            (gcc, creates libpng.so.2.1.0.11beta1)
+                            (gcc, creates libpng.so.2.1.0.11beta2)
        makefile.sco     =>  For SCO OSr5  ELF and Unixware 7 with Native cc
        makefile.mips    =>  MIPS makefile
        makefile.acorn   =>  Acorn makefile
diff --git a/Y2KINFO b/Y2KINFO
index 0576337..e94f56f 100644
--- a/Y2KINFO
+++ b/Y2KINFO
@@ -1,13 +1,13 @@
    Y2K compliance in libpng:
    =========================
 
-      April 4, 2001
+      April 11, 2001
 
       Since the PNG Development group is an ad-hoc body, we can't make
       an official declaration.
 
       This is your unofficial assurance that libpng from version 0.71 and
-      upward through 1.0.11beta1 are Y2K compliant.  It is my belief that earlier
+      upward through 1.0.11beta2 are Y2K compliant.  It is my belief that earlier
       versions were also Y2K compliant.
 
       Libpng only has three year fields.  One is a 2-byte unsigned integer
diff --git a/configure b/configure
index 41bb25b..63ed427 100755
--- a/configure
+++ b/configure
@@ -1,5 +1,5 @@
 echo "
-  There is no \"configure\" script for Libpng-1.0.11beta1.  Instead, please
+  There is no \"configure\" script for Libpng-1.0.11beta2.  Instead, please
   copy the appropriate makefile for your system from the \"scripts\"
   directory.  Read the INSTALL file for more details.
 "
diff --git a/libpng.3 b/libpng.3
index 10f0f9f..88d775b 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "April 4, 2001"
+.TH LIBPNG 3 "April 11, 2001"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.0.11beta1
+libpng \- Portable Network Graphics (PNG) Reference Library 1.0.11beta2
 .SH SYNOPSIS
 \fI\fB
 
@@ -747,7 +747,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.0.11beta1 - April 4, 2001
+ libpng version 1.0.11beta2 - April 11, 2001
  Updated and distributed by Glenn Randers-Pehrson
  <randeg@alum.rpi.edu>
  Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
@@ -3464,13 +3464,13 @@
 
 .SH VIII. Y2K Compliance in libpng
 
-April 4, 2001
+April 11, 2001
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.0.11beta1 are Y2K compliant.  It is my belief that earlier
+upward through 1.0.11beta2 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -3579,7 +3579,7 @@
  1.0.10beta1          1    10010  2.1.0.10beta1
  1.0.10rc1            1    10010  2.1.0.10rc1
  1.0.10               1    10010  2.1.0.10
- 1.0.11beta1          1    10011  2.1.0.11beta1
+ 1.0.11beta1-2        1    10011  2.1.0.11beta1-2
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -3637,7 +3637,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.0.11beta1 - April 4, 2001:
+Libpng version 1.0.11beta2 - April 11, 2001:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (randeg@alum.rpi.edu).
 
@@ -3654,7 +3654,7 @@
 If you modify libpng you may insert additional notices immediately following
 this sentence.
 
-libpng versions 1.0.7, July 1, 2000, through  1.0.11beta1, April 4, 2001, are
+libpng versions 1.0.7, July 1, 2000, through  1.0.11beta2, April 11, 2001, are
 Copyright (c) 2000-2001 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.0.6
 with the following individuals added to the list of Contributing Authors
@@ -3746,7 +3746,7 @@
 
 Glenn Randers-Pehrson
 randeg@alum.rpi.edu
-April 4, 2001
+April 11, 2001
 
 .\" end of man page
 
diff --git a/libpng.txt b/libpng.txt
index e65cb05..2f0d84b 100644
--- a/libpng.txt
+++ b/libpng.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.0.11beta1 - April 4, 2001
+ libpng version 1.0.11beta2 - April 11, 2001
  Updated and distributed by Glenn Randers-Pehrson
  <randeg@alum.rpi.edu>
  Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
@@ -2717,13 +2717,13 @@
 
 VIII. Y2K Compliance in libpng
 
-April 4, 2001
+April 11, 2001
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.0.11beta1 are Y2K compliant.  It is my belief that earlier
+upward through 1.0.11beta2 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpngpf.3 b/libpngpf.3
index a6c0392..0e35d00 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "April 4, 2001"
+.TH LIBPNGPF 3 "April 11, 2001"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.0.11beta1
+libpng \- Portable Network Graphics (PNG) Reference Library 1.0.11beta2
 (private functions)
 .SH SYNOPSIS
 \fB#include <png.h>\fP
diff --git a/png.5 b/png.5
index 27aa6b2..33a996f 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "April 4, 2001"
+.TH PNG 5 "April 11, 2001"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/pngasmrd.h b/pngasmrd.h
index fd5ca88..d6d02cd 100644
--- a/pngasmrd.h
+++ b/pngasmrd.h
@@ -1,6 +1,6 @@
 /* pngasmrd.h - assembler version of utilities to read a PNG file
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 2001 Glenn Randers-Pehrson
  *
diff --git a/pngconf.h b/pngconf.h
index 5d9a4c4..ae486bb 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,6 +1,6 @@
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -1185,10 +1185,15 @@
 #    endif
 #    define PNGAPI __cdecl
 #  else
-#    if 0 /* ... other platforms, with other meanings */
+#    if (defined(__IBMC__) || defined(IBMCPP__)) && defined(__OS2__)
+#      define PNGAPI _System
+#      define PNG_IMPEXP
 #    else
-#       define PNGAPI
-#       define PNG_IMPEXP
+#      if 0 /* ... other platforms, with other meanings */
+#      else
+#        define PNGAPI
+#        define PNG_IMPEXP
+#      endif
 #    endif
 #  endif
 #endif
diff --git a/pngerror.c b/pngerror.c
index 4858ee5..dc4c13d 100644
--- a/pngerror.c
+++ b/pngerror.c
@@ -1,7 +1,7 @@
 
 /* pngerror.c - stub functions for i/o and memory allocation
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pnggccrd.c b/pnggccrd.c
index cf38b56..a5b1228 100644
--- a/pnggccrd.c
+++ b/pnggccrd.c
@@ -6,7 +6,7 @@
  *     and http://www.intel.com/drg/pentiumII/appnotes/923/923.htm
  *     for Intel's performance analysis of the MMX vs. non-MMX code.
  *
- * libpng version 1.0.11beta1 - April 4, 2001
+ * libpng version 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * Copyright (c) 1998, Intel Corporation
diff --git a/pngget.c b/pngget.c
index cb16335..a413948 100644
--- a/pngget.c
+++ b/pngget.c
@@ -1,7 +1,7 @@
 
 /* pngget.c - retrieval of values from info struct
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngmem.c b/pngmem.c
index d04825c..c9bfd2c 100644
--- a/pngmem.c
+++ b/pngmem.c
@@ -1,7 +1,7 @@
 
 /* pngmem.c - stub functions for memory allocation
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpread.c b/pngpread.c
index 876134a..e70d1f0 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1,7 +1,7 @@
 
 /* pngpread.c - read a png file in push mode
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index c571e82..9498538 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
 
 /* pngread.c - read a PNG file
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -715,7 +715,7 @@
  * not called png_set_interlace_handling(), the display_row buffer will
  * be ignored, so pass NULL to it.
  *
- * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.11beta1
+ * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.11beta2
  */
 
 void PNGAPI
@@ -764,7 +764,7 @@
  * only call this function once.  If you desire to have an image for
  * each pass of a interlaced image, use png_read_rows() instead.
  *
- * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.11beta1
+ * [*] png_handle_alpha() does not exist yet, as of libpng version 1.0.11beta2
  */
 void PNGAPI
 png_read_image(png_structp png_ptr, png_bytepp image)
@@ -1052,7 +1052,7 @@
 }
 
 /* free all memory used by the read (old method) */
-void PNGAPI
+void /* PRIVATE */
 png_read_destroy(png_structp png_ptr, png_infop info_ptr, png_infop end_info_ptr)
 {
 #ifdef PNG_SETJMP_SUPPORTED
diff --git a/pngrio.c b/pngrio.c
index ad35cae..2edced7 100644
--- a/pngrio.c
+++ b/pngrio.c
@@ -1,7 +1,7 @@
 
 /* pngrio.c - functions for data input
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngrtran.c b/pngrtran.c
index 2cefedf..c85bf82 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
 
 /* pngrtran.c - transforms the data in a row for PNG readers
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngrutil.c b/pngrutil.c
index 6d13755..5b9b745 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
 
 /* pngrutil.c - utilities to read a PNG file
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngset.c b/pngset.c
index 8565d3e..0ee46a7 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index d73c85c..972576c 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1,7 +1,7 @@
 
 /* pngtest.c - a simple test program to test libpng
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -1523,4 +1523,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_0_11beta1 your_png_h_is_not_version_1_0_11beta1;
+typedef version_1_0_11beta2 your_png_h_is_not_version_1_0_11beta2;
diff --git a/pngtrans.c b/pngtrans.c
index 2fb1126..ebeda25 100644
--- a/pngtrans.c
+++ b/pngtrans.c
@@ -1,7 +1,7 @@
 
 /* pngtrans.c - transforms the data in a row (used by both readers and writers)
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngvcrd.c b/pngvcrd.c
index cab8ea3..13d882d 100644
--- a/pngvcrd.c
+++ b/pngvcrd.c
@@ -2,7 +2,7 @@
  *
  * For Intel x86 CPU and Microsoft Visual C++ compiler
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * Copyright (c) 1998, Intel Corporation
diff --git a/pngwio.c b/pngwio.c
index 4db33ec..f25ac14 100644
--- a/pngwio.c
+++ b/pngwio.c
@@ -1,7 +1,7 @@
 
 /* pngwio.c - functions for data output
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngwrite.c b/pngwrite.c
index 659d2c0..1678358 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
 
 /* pngwrite.c - general routines to write a PNG file
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -925,7 +925,7 @@
 
 
 /* Free any memory used in png_ptr struct (old method) */
-void PNGAPI
+void /* PRIVATE */
 png_write_destroy(png_structp png_ptr)
 {
 #ifdef PNG_SETJMP_SUPPORTED
diff --git a/pngwtran.c b/pngwtran.c
index c002b74..a77ede4 100644
--- a/pngwtran.c
+++ b/pngwtran.c
@@ -1,7 +1,7 @@
 
 /* pngwtran.c - transforms the data in a row for PNG writers
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngwutil.c b/pngwutil.c
index eaaa99b..92bdec5 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -1,7 +1,7 @@
 
 /* pngwutil.c - utilities to write a PNG file
  *
- * libpng 1.0.11beta1 - April 4, 2001
+ * libpng 1.0.11beta2 - April 11, 2001
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/msvc/README.txt b/projects/msvc/README.txt
index c5889e6..aee9707 100644
--- a/projects/msvc/README.txt
+++ b/projects/msvc/README.txt
@@ -1,5 +1,5 @@
 Microsoft Developer Studio Build File, Format Version 6.00 for
-libpng 1.0.11beta1 (April 4, 2001) and zlib
+libpng 1.0.11beta2 (April 11, 2001) and zlib
 
 Copyright (C) 2000 Simon-Pierre Cadieux
 For conditions of distribution and use, see copyright notice in png.h
diff --git a/projects/msvc/png32ms.def b/projects/msvc/png32ms.def
index 188ab16..6ca6910 100644
--- a/projects/msvc/png32ms.def
+++ b/projects/msvc/png32ms.def
@@ -6,7 +6,7 @@
 DESCRIPTION "PNG image compression library for Windows"
 
 EXPORTS
-;Version 1.0.11beta1
+;Version 1.0.11beta2
   png_build_grayscale_palette  @1
   png_check_sig        @2
   png_chunk_error      @3
@@ -83,7 +83,7 @@
   png_read_end    @74
   png_read_image    @75
   png_read_info    @76
-  png_read_init    @77
+  png_read_init    @77 ; deprecated
   png_read_png    @78
   png_read_row    @79
   png_read_rows    @80
@@ -168,7 +168,7 @@
   png_write_image    @159
   png_write_info    @160
   png_write_info_before_PLTE  @161
-  png_write_init    @162
+  png_write_init    @162 ; deprecated
   png_write_png    @163
   png_write_row    @164
   png_write_rows    @165
diff --git a/projects/wince/READMEE.WCE b/projects/wince/READMEE.WCE
index 83d5566..7177d82 100644
--- a/projects/wince/READMEE.WCE
+++ b/projects/wince/READMEE.WCE
@@ -8,9 +8,9 @@
 
 Introduction
 ============
-This is libpng 1.0.11beta1 ported to WindowsCE 2.0 and 2.11.
-libpng 1.0.11beta1 is a PNG reference library.
-See README, a document of original libpng 1.0.11beta1.
+This is libpng 1.0.11beta2 ported to WindowsCE 2.0 and 2.11.
+libpng 1.0.11beta2 is a PNG reference library.
+See README, a document of original libpng 1.0.11beta2.
 
 zlib for WindowsCE
 ==================
@@ -23,7 +23,7 @@
 warranty.  In no event will the authors be held liable for any damages
 arising from the use of this software.
 
-See README and LICENSE, documents of original libpng 1.0.11beta1, for conditions
+See README and LICENSE, documents of original libpng 1.0.11beta2, for conditions
 of use and distribution.
 
 Files
diff --git a/projects/wince/READMEJ.WCE b/projects/wince/READMEJ.WCE
index 21212f6..af88d00 100644
--- a/projects/wince/READMEJ.WCE
+++ b/projects/wince/READMEJ.WCE
@@ -24,7 +24,7 @@
 ‚É‚È‚Á‚½‚¢‚©‚È‚é”íŠQ‚ɂ‚¢‚Ä‚àAìŽÒA”z•zŽÒA‚»‚Ì‘¼—˜—pŽÒˆÈŠO‚̐l•¨A
 ’c‘̂ɐӔC‚ð‚Æ‚é‹`–±‚Í‚È‚¢‚à‚Ì‚Æ‚µ‚Ü‚·B
 
-‚»‚Ì‘¼A‚±‚̃\ƒtƒgƒEƒFƒA‚Ì—˜—pðŒ‚ɂ‚¢‚ẮAŒ´”Å‚Å‚ ‚é libpng 1.0.11beta1‚É
+‚»‚Ì‘¼A‚±‚̃\ƒtƒgƒEƒFƒA‚Ì—˜—pðŒ‚ɂ‚¢‚ẮAŒ´”Å‚Å‚ ‚é libpng 1.0.11beta2‚É
 €‹’‚·‚é‚à‚Ì‚Æ‚µ‚Ü‚·BÚ‚µ‚­‚́A•t‘®‚Ì README,LICENSE ‚ð‚¨“Ç‚Ý‚­‚¾‚³‚¢B
 
 Žû˜^“à—e
diff --git a/projects/wince/png32ce.def b/projects/wince/png32ce.def
index 2b5e10c..f24ea42 100644
--- a/projects/wince/png32ce.def
+++ b/projects/wince/png32ce.def
@@ -5,7 +5,7 @@
 LIBRARY lpngce
 
 EXPORTS
-;Version 1.0.11beta1
+;Version 1.0.11beta2
   png_build_grayscale_palette  @1
   png_check_sig        @2
   png_chunk_error      @3
@@ -82,7 +82,7 @@
   png_read_end    @74
   png_read_image    @75
   png_read_info    @76
-  png_read_init    @77
+  png_read_init    @77 ; deprecated
   png_read_png    @78
   png_read_row    @79
   png_read_rows    @80
@@ -167,7 +167,7 @@
   png_write_image    @159
   png_write_info    @160
   png_write_info_before_PLTE  @161
-  png_write_init    @162
+  png_write_init    @162 ; deprecated
   png_write_png    @163
   png_write_row    @164
   png_write_rows    @165
diff --git a/scripts/makefile.aix b/scripts/makefile.aix
index d5d91ab..fa7814f 100644
--- a/scripts/makefile.aix
+++ b/scripts/makefile.aix
@@ -18,7 +18,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 prefix=/usr/local
diff --git a/scripts/makefile.beos b/scripts/makefile.beos
index e476d16..39ee92c 100644
--- a/scripts/makefile.beos
+++ b/scripts/makefile.beos
@@ -13,7 +13,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 ALIGN=
diff --git a/scripts/makefile.cygwin b/scripts/makefile.cygwin
index 8ffdb61..f1c08d9 100644
--- a/scripts/makefile.cygwin
+++ b/scripts/makefile.cygwin
@@ -39,8 +39,8 @@
 # have to change it.
 PNGMAJ = 2
 #PNGDLL = $1# msvc
-PNGDLL = 2# cygwin 1.0.11beta1
-PNGMIN = 1.0.11beta1
+PNGDLL = 2# cygwin 1.0.11beta2
+PNGMIN = 1.0.11beta2
 PNGMIN_BASE = 1.0.11
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
diff --git a/scripts/makefile.dec b/scripts/makefile.dec
index 64c5d35..3a31ebf 100644
--- a/scripts/makefile.dec
+++ b/scripts/makefile.dec
@@ -17,7 +17,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 CC=cc
diff --git a/scripts/makefile.gcmmx b/scripts/makefile.gcmmx
index cd655aa..4c19397 100644
--- a/scripts/makefile.gcmmx
+++ b/scripts/makefile.gcmmx
@@ -51,7 +51,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 INCPATH=$(prefix)/include
diff --git a/scripts/makefile.hpgcc b/scripts/makefile.hpgcc
index 3f1cbb4..00c0b18 100644
--- a/scripts/makefile.hpgcc
+++ b/scripts/makefile.hpgcc
@@ -34,7 +34,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 INCPATH=$(prefix)/include
diff --git a/scripts/makefile.hpux b/scripts/makefile.hpux
index faa52a3..88263d0 100644
--- a/scripts/makefile.hpux
+++ b/scripts/makefile.hpux
@@ -19,7 +19,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 # where make install puts libpng.a and png.h
diff --git a/scripts/makefile.linux b/scripts/makefile.linux
index 5a0b407..467ccbe 100644
--- a/scripts/makefile.linux
+++ b/scripts/makefile.linux
@@ -34,7 +34,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 INCPATH=$(prefix)/include
diff --git a/scripts/makefile.sco b/scripts/makefile.sco
index 937f7d2..d016a9d 100644
--- a/scripts/makefile.sco
+++ b/scripts/makefile.sco
@@ -25,7 +25,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 INCPATH=$(prefix)/include
diff --git a/scripts/makefile.sggcc b/scripts/makefile.sggcc
index 844312e..d497f7a 100644
--- a/scripts/makefile.sggcc
+++ b/scripts/makefile.sggcc
@@ -19,8 +19,8 @@
 LDFLAGS=-L. -L$(ZLIBLIB) -lpng -lz -lm
 LDSHARED=gcc -shared
 
-VER=1.0.11beta1
-LIBS=libpng.so.1.0.11beta1
+VER=1.0.11beta2
+LIBS=libpng.so.1.0.11beta2
 SHAREDLIB=libpng.so
 libdir=$(prefix)/lib32
 
diff --git a/scripts/makefile.sgi b/scripts/makefile.sgi
index c14655b..7e1cbbd 100644
--- a/scripts/makefile.sgi
+++ b/scripts/makefile.sgi
@@ -25,7 +25,7 @@
 LDFLAGS=-L. -L$(ZLIBLIB) -lpng -lz -lm
 LDSHARED=cc -shared
 
-VER=1.0.11beta1
+VER=1.0.11beta2
 SONUM=2
 SHAREDLIB=libpng.so
 libdir=$(prefix)
diff --git a/scripts/makefile.solaris b/scripts/makefile.solaris
index ff1dd94..6d58b79 100644
--- a/scripts/makefile.solaris
+++ b/scripts/makefile.solaris
@@ -31,7 +31,7 @@
 # read libpng.txt or png.h to see why PNGMAJ is 2.  You should not
 # have to change it.
 PNGMAJ = 2
-PNGMIN = 1.0.11beta1
+PNGMIN = 1.0.11beta2
 PNGVER = $(PNGMAJ).$(PNGMIN)
 
 INCPATH=$(prefix)/include
diff --git a/scripts/pngdef.pas b/scripts/pngdef.pas
index f025eba..aa499c1 100644
--- a/scripts/pngdef.pas
+++ b/scripts/pngdef.pas
@@ -1,11 +1,13 @@
 unit pngdef;
 
-// Caution: this file is probably out of date.
+// Caution: this file has fallen out of date since version 1.0.5.  Write to
+// png-implement@ccrc.wustl.edu or to randeg@alum.rpi.edu about bringing
+// it up to date.
 
 interface
 
 const
-  PNG_LIBPNG_VER_STRING = '1.0.11beta1';
+  PNG_LIBPNG_VER_STRING = '1.0.11beta2';
   PNG_LIBPNG_VER        =  10011;
 
 type
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index 7d8841e..407345f 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
 ; PNG.LIB module definition file for OS/2
 ;----------------------------------------
 
-; Caution: This file is probably out of date.
+; Version 1.0.11beta2
 
 LIBRARY		PNG
 DESCRIPTION	"PNG image compression library for OS/2"
@@ -10,284 +10,187 @@
 DATA		PRELOAD MOVEABLE MULTIPLE
 
 EXPORTS
-  png_set_sig_bytes
-  png_sig_cmp
+
+
+  png_build_grayscale_palette
   png_check_sig
-  png_create_read_struct
-; png_create_read_struct_2
-  png_create_write_struct
-; png_create_write_struct_2
-  png_write_chunk
-  png_write_chunk_start
-  png_write_chunk_data
-  png_write_chunk_end
-  png_create_info_struct
-  png_info_init
-  png_write_info
-  png_write_info_before_PLTE
-  png_read_info
-  png_convert_to_rfc1123
+  png_chunk_error
+  png_chunk_warning
   png_convert_from_struct_tm
   png_convert_from_time_t
-  png_set_expand
+  png_create_info_struct
+  png_create_read_struct
+  png_create_write_struct
+  png_data_freer
+  png_destroy_info_struct
+  png_destroy_read_struct
+  png_destroy_write_struct
+  png_error
+  png_free
+  png_free_data
+  png_get_IHDR
+  png_get_PLTE
+  png_get_bKGD
+  png_get_bit_depth
+  png_get_cHRM
+  png_get_cHRM_fixed
+  png_get_channels
+  png_get_color_type
+  png_get_compression_buffer_size
+  png_get_compression_type
+  png_get_copyright
+  png_get_error_ptr
+  png_get_filter_type
+  png_get_gAMA
+  png_get_gAMA_fixed
+  png_get_hIST
+  png_get_header_ver
+  png_get_header_version
+  png_get_iCCP
+  png_get_image_height
+  png_get_image_width
+  png_get_interlace_type
+  png_get_io_ptr
+  png_get_libpng_ver
+  png_get_oFFs
+  png_get_pCAL
+  png_get_pHYs
+  png_get_pixel_aspect_ratio
+  png_get_pixels_per_meter
+  png_get_progressive_ptr
+  png_get_rgb_to_gray_status
+  png_get_rowbytes
+  png_get_rows
+  png_get_sBIT
+  png_get_sCAL
+  png_get_sPLT
+  png_get_sRGB
+  png_get_signature
+  png_get_tIME
+  png_get_tRNS
+  png_get_text
+  png_get_unknown_chunks
+  png_get_user_chunk_ptr
+  png_get_user_transform_ptr
+  png_get_valid
+  png_get_x_offset_microns
+  png_get_x_offset_pixels
+  png_get_x_pixels_per_meter
+  png_get_y_offset_microns
+  png_get_y_offset_pixels
+  png_get_y_pixels_per_meter
+  png_malloc
+  png_memcpy_check
+  png_memset_check
+  png_permit_empty_plte
+  png_process_data
+  png_progressive_combine_row
+  png_read_end
+  png_read_image
+  png_read_info
+  png_read_init ; deprecated
+  png_read_png
+  png_read_row
+  png_read_rows
+  png_read_update_info
+  png_reset_zstream
+  png_set_IHDR
+  png_set_PLTE
+  png_set_bKGD
+  png_set_background
   png_set_bgr
+  png_set_cHRM
+  png_set_cHRM_fixed
+  png_set_compression_buffer_size
+  png_set_compression_level
+  png_set_compression_mem_level
+  png_set_compression_method
+  png_set_compression_strategy
+  png_set_compression_window_bits
+  png_set_crc_action
+  png_set_dither
+  png_set_error_fn
+  png_set_expand
+  png_set_filler
+  png_set_filter
+  png_set_filter_heuristics
+  png_set_flush
+  png_set_gAMA
+  png_set_gAMA_fixed
+  png_set_gamma
+  png_set_gray_1_2_4_to_8
   png_set_gray_to_rgb
+  png_set_hIST
+  png_set_iCCP
+  png_set_interlace_handling
+  png_set_invert_alpha
+  png_set_invert_mono
+  png_set_keep_unknown_chunks
+  png_set_oFFs
+  png_set_pCAL
+  png_set_pHYs
+  png_set_packing
+  png_set_packswap
+  png_set_palette_to_rgb
+  png_set_progressive_read_fn
+  png_set_read_fn
+  png_set_read_status_fn
+  png_set_read_user_chunk_fn
+  png_set_read_user_transform_fn
   png_set_rgb_to_gray
   png_set_rgb_to_gray_fixed
   png_set_rows
-  png_build_grayscale_palette
-  png_set_strip_alpha
-  png_set_swap_alpha
-  png_set_invalid
-  png_set_invert_alpha
-  png_set_filler
-  png_set_swap
-  png_set_packing
-  png_set_packswap
-  png_set_shift
-  png_set_interlace_handling
-  png_set_invert_mono
-  png_set_background
-  png_set_strip_16
-  png_set_dither
-  png_set_gamma
-  png_set_flush
-  png_set_user_chunk_fn
-  png_write_flush
-  png_start_read_image
-  png_read_update_info
-  png_read_rows
-  png_read_row
-  png_read_image
-  png_write_row
-  png_write_rows
-  png_write_image
-  png_write_end
-  png_read_end
-  png_destroy_info_struct
-  png_destroy_read_struct
-  png_read_destroy
-  png_destroy_write_struct
-; png_write_destroy_info
-  png_write_destroy
-  png_set_crc_action
-  png_set_filter
-  png_set_filter_heuristics
-  png_set_compression_level
-  png_set_compression_mem_level
-  png_set_compression_strategy
-  png_set_compression_window_bits
-  png_set_compression_method
-  png_init_io
-  png_get_copyright
-  png_set_error_fn
-  png_get_error_ptr
-  png_get_header_ver
-  png_get_header_version
-  png_get_libpng_ver
-  png_get_user_chunk_ptr
-; png_get_mem_fn
-; png_set_mem_fn
-  png_set_write_fn
-  png_set_read_fn
-  png_set_write_status_fn
-  png_set_read_status_fn
-  png_get_io_ptr
-  png_set_progressive_read_fn
-  png_set_read_status_fn
-  png_set_read_user_transform_fn
-  png_set_write_status_fn
-  png_set_write_user_transform_fn
-  png_get_progressive_ptr
-  png_process_data
-  png_progressive_combine_row
-  png_malloc
-  png_free
-  png_memcpy_check
-  png_memset_check
-; png_malloc_default
-; png_free_default
-; png_far_to_near
-  png_error
-  png_chunk_error
-  png_warning
-  png_chunk_warning
-  png_get_valid
-  png_get_rowbytes
-  png_get_channels
-  png_get_image_width
-  png_get_image_height
-  png_get_bit_depth
-  png_get_color_type
-  png_get_filter_type
-  png_get_interlace_type
-  png_get_compression_type
-  png_get_pixels_per_meter
-  png_get_pixel_aspect_ratio
-  png_get_rgb_to_gray_status
-  png_get_rows
-  png_get_x_offset_pixels
-  png_get_y_offset_pixels
-  png_get_x_offset_microns
-  png_get_y_offset_microns
-  png_get_signature
-  png_get_bKGD
-  png_set_bKGD
-  png_get_cHRM
-  png_set_cHRM
-  png_set_cHRM_fixed
-  png_get_gAMA
-  png_set_gAMA
-  png_set_gAMA_fixed
-  png_get_hIST
-  png_set_hIST
-  png_get_IHDR
-  png_set_IHDR
-  png_get_oFFs
-  png_set_oFFs
-  png_get_pCAL
-  png_set_pCAL
-  png_get_pHYs
-  png_set_pHYs
-  png_get_PLTE
-  png_set_PLTE
-  png_get_sBIT
   png_set_sBIT
-  png_get_sRGB
+  png_set_sCAL
+  png_set_sPLT
   png_set_sRGB
   png_set_sRGB_gAMA_and_cHRM
-  png_get_text
-  png_set_text
-  png_get_tIME
+  png_set_shift
+  png_set_sig_bytes
+  png_set_strip_16
+  png_set_strip_alpha
+  png_set_swap
+  png_set_swap_alpha
   png_set_tIME
-  png_get_tRNS
   png_set_tRNS
-  png_set_gray_1_2_4_to_8
   png_set_tRNS_to_alpha
-  png_set_palette_to_rgb
+  png_set_text
+  png_set_unknown_chunk_location
+  png_set_unknown_chunks
+  png_set_user_transform_info
+  png_set_write_fn
+  png_set_write_status_fn
+  png_set_write_user_transform_fn
+  png_sig_cmp
+  png_start_read_image
+  png_warning
+  png_write_chunk
+  png_write_chunk_data
+  png_write_chunk_end
+  png_write_chunk_start
+  png_write_end
+  png_write_flush
+  png_write_image
+  png_write_info
+  png_write_info_before_PLTE
+  png_write_init ; deprecated
+  png_write_png
+  png_write_row
+  png_write_rows
+  png_read_init_2
+  png_write_init_2
+  png_access_version_number
+  png_init_io
+  png_convert_to_rfc1123
+  png_set_invalid
 
-  png_create_struct
-  png_destroy_struct
-  png_info_destroy
-  png_zalloc
-  png_zfree
-  png_reset_crc
-  png_write_data
-  png_read_data
-  png_crc_read
-  png_crc_finish
-  png_crc_error
-  png_calculate_crc
-  png_flush
-  png_save_uint_32
-  png_save_int_32
-  png_save_uint_16
-  png_write_sig
-  png_write_IHDR
-  png_write_PLTE
-  png_write_IDAT
-  png_write_IEND
-  png_write_bKGD
-  png_write_cHRM
-  png_write_gAMA
-  png_write_hIST
-  png_write_iCCP
-  png_write_iTXt
-  png_write_oFFs
-  png_write_pCAL
-  png_write_pHYs
-  png_write_sBIT
-  png_write_sCAL
-  png_write_sPLT
-  png_write_sRGB
-  png_check_keyword
-  png_write_tEXt
-  png_write_tIME
-  png_write_tRNS
-  png_write_zTXt
-  png_write_finish_row
-  png_write_start_row
-  png_build_gamma_table
-  png_combine_row
-  png_do_read_interlace
-  png_do_write_interlace
-  png_read_filter_row
-  png_write_find_filter
-  png_write_filtered_row
-  png_read_finish_row
-  png_read_start_row
-  png_read_transform_info
-  png_do_read_filler
-  png_do_read_swap_alpha
-  png_do_write_swap_alpha
-  png_do_read_invert_alpha
-  png_do_write_invert_alpha
-  png_do_strip_filler
-  png_do_swap
-  png_do_packswap
-  png_do_rgb_to_gray
-  png_do_gray_to_rgb
-  png_do_unpack
-  png_do_unshift
-  png_do_invert
-  png_do_chop
-  png_do_dither
-; png_correct_palette
-  png_do_bgr
-  png_do_pack
-  png_do_shift
-  png_do_background
-  png_do_gamma
-  png_do_expand_palette
-  png_do_expand
-  png_handle_IHDR
-  png_handle_PLTE
-  png_handle_IEND
-  png_handle_bKGD
-  png_handle_cHRM
-  png_handle_gAMA
-  png_handle_hIST
-  png_handle_iCCP
-  png_handle_iTXt
-  png_handle_oFFs
-  png_handle_pCAL
-  png_handle_pHYs
-  png_handle_sBIT
-  png_handle_sCAL
-  png_handle_sPLT
-  png_handle_sRGB
-  png_handle_tEXt
-  png_handle_tIME
-  png_handle_tRNS
-  png_handle_zTXt
-  png_handle_unknown
-  png_check_chunk_name
-  png_do_read_transformations
-  png_do_write_transformations
-  png_init_read_transformations
-  png_push_read_chunk
-  png_push_read_sig
-; png_push_check_crc
-  png_push_crc_skip
-  png_push_crc_finish
-  png_push_fill_buffer
-  png_push_save_buffer
-  png_push_restore_buffer
-  png_push_read_IDAT
-  png_process_IDAT_data
-  png_push_process_row
-  png_push_handle_unknown
-  png_push_have_info
-  png_push_have_end
-  png_push_have_row
-; png_push_read_end
-  png_process_some_data
-  png_read_push_finish_row
-  png_push_handle_tEXt
-  png_push_read_tEXt
-  png_push_handle_zTXt
-  png_push_read_zTXt
+;To be added at version 1.2.0
+; png_permit_mng_features
 
+;To be added at version 1.2.0
+; png_mmx_support
+
+; These are not present when libpng is compiled with PNG_NO_GLOBAL_ARRAYS
   png_libpng_ver
   png_pass_start
   png_pass_inc
@@ -297,13 +200,8 @@
   png_pass_dsp_mask
 ; png_pass_width
 ; png_pass_height
-  png_get_iCCP
-  png_get_sCAL
-  png_get_sPLT
-  png_set_iCCP
-  png_set_sPLT
-  png_free_data
 
+; These are not present when libpng is compiled with PNG_NO_GLOBAL_ARRAYS
   png_IHDR
   png_IDAT
   png_IEND
@@ -325,6 +223,3 @@
   png_tIME
   png_tRNS
   png_zTXt
-
-  png_mmx_supported
-  png_permit_empty_plte
diff --git a/png.c b/png.c
index 6686135..d392d83 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
 
 /* png.c - location for general purpose libpng functions
  *
  * libpng version 1.0.11beta1 - April 4, 2001
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -13,14 +13,14 @@
 #include "png.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_0_11beta1 Your_png_h_is_not_version_1_0_11beta1;
+typedef version_1_0_11beta2 Your_png_h_is_not_version_1_0_11beta2;
 
 /* Version information for C files.  This had better match the version
  * string defined in png.h.  */
 
 #ifdef PNG_USE_GLOBAL_ARRAYS
 /* png_libpng_ver was changed to a function in version 1.0.5c */
-const char png_libpng_ver[18] = "1.0.11beta1";
+const char png_libpng_ver[18] = "1.0.11beta2";
 
 /* png_sig was changed to a function in version 1.0.5c */
 /* Place to hold the signature string for a PNG file. */
@@ -135,7 +135,7 @@
 }
 
 /* Function to allocate memory for zlib and clear it to 0. */
-voidpf PNGAPI
+voidpf /* PRIVATE */
 png_zalloc(voidpf png_ptr, uInt items, uInt size)
 {
    png_uint_32 num_bytes = (png_uint_32)items * size;
@@ -157,7 +157,7 @@
 }
 
 /* function to free memory for zlib */
-void PNGAPI
+void /* PRIVATE */
 png_zfree(voidpf png_ptr, voidpf ptr)
 {
    png_free((png_structp)png_ptr, (png_voidp)ptr);
@@ -255,7 +255,7 @@
  * and applications using it are urged to use png_create_info_struct()
  * instead.
  */
-void PNGAPI
+void /* PRIVATE */
 png_info_init(png_infop info_ptr)
 {
    png_debug(1, "in png_info_init\n");
@@ -626,7 +626,7 @@
 png_get_copyright(png_structp png_ptr)
 {
    if (png_ptr != NULL || png_ptr == NULL)  /* silence compiler warning */
-   return ((png_charp) "\n libpng version 1.0.11beta1 - April 4, 2001\n\
+   return ((png_charp) "\n libpng version 1.0.11beta2 - April 11, 2001\n\
    Copyright (c) 1998-2001 Glenn Randers-Pehrson\n\
    Copyright (c) 1996, 1997 Andreas Dilger\n\
    Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.\n");
@@ -644,8 +644,8 @@
 {
    /* Version of *.c files used when building libpng */
    if(png_ptr != NULL) /* silence compiler warning about unused png_ptr */
-      return((png_charp) "1.0.11beta1");
-   return((png_charp) "1.0.11beta1");
+      return((png_charp) "1.0.11beta2");
+   return((png_charp) "1.0.11beta2");
 }
 
 png_charp PNGAPI
@@ -667,7 +667,7 @@
 }
 
 #ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED
-int PNGAPI
+int /* PRIVATE */
 png_handle_as_unknown(png_structp png_ptr, png_bytep chunk_name)
 {
    /* check chunk_name and return "keep" value if it's on the list, else 0 */
@@ -1,7 +1,7 @@
 /* png.c - location for general purpose libpng functions
  *
- * libpng version 1.0.11beta1 - April 4, 2001
+ * libpng version 1.0.11beta2 - April 11, 2001
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/png.h b/png.h
index b644d34..d2c1a9c 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.0.11beta1 - April 4, 2001
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.0.11beta1 - April 4, 2001: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -67,7 +67,7 @@
  *    1.0.10beta1              1    10010  2.1.0.10beta1
  *    1.0.10rc1                1    10010  2.1.0.10rc1
  *    1.0.10                   1    10010  2.1.0.10
- *    1.0.11beta1              1    10011  2.1.0.11beta1
+ *    1.0.11beta1-2            1    10011  2.1.0.11beta1-2
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -97,7 +97,7 @@
  * If you modify libpng you may insert additional notices immediately following
  * this sentence.
  *
  * libpng versions 1.0.7, July 1, 2000, through  1.0.11beta1, April 4, 2001, are
  * Copyright (c) 2000, 2001 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.0.6
  * with the following individuals added to the list of Contributing Authors
@@ -202,13 +202,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    April 4, 2001
+ *    April 11, 2001
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.0.11beta1 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -264,7 +264,7 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.11beta1"
+#define PNG_LIBPNG_VER_STRING "1.0.11beta2"
 
 #define PNG_LIBPNG_VER_SONUM   2
 #define PNG_LIBPNG_VER_DLLNUM  %DLLNUM%
@@ -276,7 +276,7 @@
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero: */
 
-#define PNG_LIBPNG_VER_BUILD  1
+#define PNG_LIBPNG_VER_BUILD  2
 
 #define PNG_LIBPNG_BUILD_ALPHA    1
 #define PNG_LIBPNG_BUILD_BETA     2
@@ -1185,9 +1185,9 @@
 
 
 /* This prevents a compiler error in png_get_copyright() in png.c if png.c
-and png.h are both at * version 1.0.11beta1
+and png.h are both at * version 1.0.11beta2
  */
-typedef png_structp version_1_0_11beta1;
+typedef png_structp version_1_0_11beta2;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -2235,7 +2235,7 @@
 /* Maintainer: Put new public prototypes here ^, in libpng.3, and project defs */
 
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.0.11beta1 - April 4, 2001 (header)\n"
+   " libpng version 1.0.11beta2 - April 11, 2001 (header)\n"
 
 #ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
 /* With these routines we avoid an integer divide, which will be slower on
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.0.11beta1 - April 4, 2001
+ * libpng version 1.0.11beta2 - April 11, 2001
  * Copyright (c) 1998-2001 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.0.11beta1 - April 4, 2001: Glenn
+ *  libpng versions 0.97, January 1998, through 1.0.11beta2 - April 11, 2001: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -97,7 +97,7 @@
  * this sentence.
  *
- * libpng versions 1.0.7, July 1, 2000, through  1.0.11beta1, April 4, 2001, are
+ * libpng versions 1.0.7, July 1, 2000, through  1.0.11beta2, April 11, 2001, are
  * Copyright (c) 2000, 2001 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.0.6
@@ -202,13 +202,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.0.11beta1 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.0.11beta2 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *